@@ -3,18 +3,29 @@
 import numpy as np
 from scipy.special import jv, yv
 from PyMieScatt.Mie import MieQ, MiePiTau
+import warnings
 
-def MieQCoreShell(mCore,mShell,wavelength,dCore,dShell, asDict=False, asCrossSection=False):
+
+def MieQCoreShell(mCore,mShell,wavelength,dCore,dShell,nMedium=1.0,asDict=False, asCrossSection=False):
 #    http://pymiescatt.readthedocs.io/en/latest/forwardCS.html#MieQCoreShell
+    if(nMedium != 1.0):
+        warnings.warn("Note: the use of nMedium was incorporated naievely and the result should be carefully scrutinized.")
     xCore = np.pi*dCore/wavelength
     xShell = np.pi*dShell/wavelength
     if xCore==xShell:
-        return MieQ(mCore,wavelength,dShell)
+        return MieQ(mCore,wavelength,dShell,nMedium=nMedium, asDict=asDict, asCrossSection=asCrossSection)
     elif xCore==0:
-        return MieQ(mShell,wavelength,dShell)
+        return MieQ(mShell,wavelength,dShell,nMedium=nMedium, asDict=asDict, asCrossSection=asCrossSection)
     elif mCore==mShell:
-        return MieQ(mCore,wavelength,dShell)
+        return MieQ(mCore,wavelength,dShell,nMedium=nMedium, asDict=asDict, asCrossSection=asCrossSection)
     elif xCore>0:
+        nMedium = nMedium.real
+        # wavelength /= nMedium  # The choice was either to redefine the wavelength, or the xCore & xShell, I left just for indication, your call.
+        mCore /= nMedium
+        mShell /= nMedium
+        xCore = np.pi*dCore * nMedium/wavelength # Not ideal to redefine xCore and xShell, but it seems need in order to keep MieQ conditions in place
+        xShell = np.pi*dShell * nMedium/wavelength
+        
         nmax = np.round(2+xShell+4*(xShell**(1/3)))
         n = np.arange(1,nmax+1)
         n1 = 2*n+1
@@ -43,7 +54,7 @@ def MieQCoreShell(mCore,mShell,wavelength,dCore,dShell, asDict=False, asCrossSec
             cabs = css*qabs
             cpr = css*qpr
             cback = css*qback
-            cratio = css*qratio
+            cratio = qratio
             if asDict:
                 return dict(Cext=cext,Csca=csca,Cabs=cabs,g=g,Cpr=cpr,Cback=cback,Cratio=cratio)
             else:
@@ -112,8 +123,13 @@ def CoreShell_ab(mCore,mShell,xCore,xShell):
 
     return an, bn
 
-def CoreShellScatteringFunction(mCore,mShell,wavelength,dCore,dShell,minAngle=0, maxAngle=180, angularResolution=0.5, normed=False):
+def CoreShellScatteringFunction(mCore,mShell,wavelength,dCore,dShell,nMedium=1.0, minAngle=0, maxAngle=180, angularResolution=0.5, normed=False):
 #    http://pymiescatt.readthedocs.io/en/latest/forwardCS.html#CoreShellScatteringFunction
+    if(nMedium != 1.0):
+        warnings.warn("Note: the use of nMedium was incorporated naievely and the result should be carefully scrutinized.")
+        mCore /= nMedium
+        mShell /= nMedium
+        wavelength /= nMedium
     xCore = np.pi*dCore/wavelength
     xShell = np.pi*dShell/wavelength
     theta = np.linspace(minAngle,maxAngle,int((maxAngle-minAngle)/angularResolution))*np.pi/180
